==> alg-feature-1.4.1-20181009.014110-2-sources.jar: cn/com/duiba/nezha/alg/feature/type/FeatureBaseType.java <==
package cn.com.duiba.nezha.alg.feature.type;

import cn.com.duiba.nezha.alg.feature.coder.FeatureCoderBase;

import java.util.List;
import java.util.Map;
import java.util.Set;

public class FeatureBaseType {

    public String name;
    public int codeType;//10: sub,11:subs    20:hash,21:hashs    30:dict,31:dicts
    public int subLen;//
    public int hashNums;//
    public String seq;
    public Map<String, Long> dictList;
    public FeatureBaseType() {
    }

    public FeatureBaseType(String name, int codeType, int subLen, int hashNums, String seq, Map<String, Long> dictList) {
        this.name = name;
        this.codeType = codeType;
        this.hashNums = hashNums;
        this.subLen = subLen;
        this.seq = seq;
        this.dictList = dictList;

    }


    public String getName() {
        return this.name;
    }

    public int getCodeType() {
        return this.codeType;
    }

    public int getSubLen() {
        return this.subLen;
    }

    public int getHashNums() {
        return this.hashNums;
    }

    public String getSeq() {
        return this.seq;
    }

    public Map<String, Long> getDictList() {
        return this.dictList;
    }


    public void setName(String name) {
        this.name = name;
    }

    public void setCodeType(int codeType) {
        this.codeType = codeType;
    }

    public void setSubLen(int subLen) {
        this.subLen = subLen;
    }

    public void setHashNums(int hashNums) {
        this.hashNums = hashNums;
    }

    public void setSeq(String seq) {
        this.seq = seq;
    }

    public void setDictList(Map<String, Long> dictList) {
        this.dictList = dictList;
    }

    public Set<Long> code(String featureValue, List<Long> pLenList, List<Integer> indices, List<Double> values) throws Exception {
        Set<Long> ret = null;
        if (codeType == 10) {
            ret = FeatureCoderBase.getSubId(this.name, featureValue, this.subLen, pLenList, indices, values);
        }
        if (codeType == 11) {
            ret = FeatureCoderBase.getSubIds(this.name, featureValue, this.seq, this.subLen, pLenList, indices, values);
        }

        if (codeType == 20) {
            ret = FeatureCoderBase.getHashSubId(this.name, featureValue, this.subLen, this.hashNums, pLenList, indices, values);
        }
        if (codeType == 21) {
            ret = FeatureCoderBase.getHashSubIds(this.name, featureValue, this.seq, this.subLen, this.hashNums, pLenList, indices, values);
        }

        if (codeType == 30) {
            ret = FeatureCoderBase.getDictSubId(this.name, featureValue, this.subLen, pLenList, indices, values, this.dictList);
        }
        if (codeType == 31) {
            ret = FeatureCoderBase.getDictSubIds(this.name, featureValue, this.seq, this.subLen, pLenList, indices, values, this.dictList);
        }
        return ret;
    }


}

==> alg-feature-1.21.5-20191008.072617-1-sources.jar: cn/com/duiba/nezha/alg/feature/type/FeatureBaseType.java <==
package cn.com.duiba.nezha.alg.feature.type;

import cn.com.duiba.nezha.alg.feature.coder.FeatureCoderBase;
import cn.com.duiba.nezha.alg.feature.coder.FeatureUtil;
import com.alibaba.fastjson.JSON;

import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class FeatureBaseType {

    public String name;
    public int codeType;//10: sub,11:subs    20:hash,21:hashs    30:dict,31:dicts
    public int subLen;//
    public int hashNums;//
    public String seq;
    public Map<String, Long> dictList;

    public int denseLen;

    public FeatureBaseType() {
    }

    public FeatureBaseType(String name, int codeType, int subLen, int hashNums, String seq, Map<String, Long> dictList) {
        this.name = name;
        this.codeType = codeType;
        this.hashNums = hashNums;
        this.subLen = subLen;
        this.seq = seq;
        this.dictList = dictList;

    }


    public String getName() {
        return this.name;
    }

    public int getCodeType() {
        return this.codeType;
    }

    public int getSubLen() {
        return this.subLen;
    }

    public int getHashNums() {
        return this.hashNums;
    }

    public String getSeq() {
        return this.seq;
    }

    public Map<String, Long> getDictList() {
        return this.dictList;
    }


    public void setName(String name) {
        this.name = name;
    }

    public void setCodeType(int codeType) {
        this.codeType = codeType;
    }

    public void setSubLen(int subLen) {
        this.subLen = subLen;
    }

    public void setHashNums(int hashNums) {
        this.hashNums = hashNums;
    }

    public void setSeq(String seq) {
        this.seq = seq;
    }

    public void setDictList(Map<String, Long> dictList) {
        this.dictList = dictList;
    }

    public int getDenseLen() {
        return denseLen;
    }

    public void setDenseLen(int denseLen) {
        this.denseLen = denseLen;
    }

    public Set<Long> code(String featureValue, List<Long> pLenList, List<Integer> indices, List<Double> values) throws Exception {
        Set<Long> ret = null;
        if (codeType == 10) {
            ret = FeatureCoderBase.getSubId(this.name, featureValue, this.subLen, pLenList, indices, values);
        }
        if (codeType == 11) {
            ret = FeatureCoderBase.getSubIds(this.name, featureValue, this.seq, this.subLen, pLenList, indices, values);
        }

        if (codeType == 20) {
            ret = FeatureCoderBase.getHashSubId(this.name, featureValue, this.subLen, this.hashNums, pLenList, indices, values);
        }
        if (codeType == 21) {
            ret = FeatureCoderBase.getHashSubIds(this.name, featureValue, this.seq, this.subLen, this.hashNums, pLenList, indices, values);
        }

        if (codeType == 30) {
            ret = FeatureCoderBase.getDictSubId(this.name, featureValue, this.subLen, pLenList, indices, values, this.dictList);
        }
        if (codeType == 31) {
            ret = FeatureCoderBase.getDictSubIds(this.name, featureValue, this.seq, this.subLen, pLenList, indices, values, this.dictList);
        }
        return ret;
    }


    public Set<Long> code(String featureValue) throws Exception {
        Set<Long> ret = null;
        if (codeType == 10) {
            ret = FeatureCoderBase.getSubId(this.name, featureValue, this.subLen);
        }
        if (codeType == 11) {
            ret = FeatureCoderBase.getSubIds(this.name, featureValue, this.seq, this.subLen);
        }

        if (codeType == 20) {
            ret = FeatureCoderBase.getHashSubId(this.name, featureValue, this.subLen, this.hashNums);
        }
        if (codeType == 21) {
            ret = FeatureCoderBase.getHashSubIds(this.name, featureValue, this.seq, this.subLen, this.hashNums);
        }

        if (codeType == 30) {
            ret = FeatureCoderBase.getDictSubId(this.name, featureValue, this.subLen, this.dictList);
        }
        if (codeType == 31) {
            ret = FeatureCoderBase.getDictSubIds(this.name, featureValue, this.seq, this.subLen, this.dictList);
        }
        return ret;
    }

    public Set<String> parseFeatureValues(String featureValue) throws Exception {
        Set<String> ret = new HashSet<>();
        System.out.println(codeType);
        if (codeType == 10 || codeType == 20 || codeType == 30) {
            ret.add(featureValue);
        }
        if (codeType == 11 || codeType == 21 || codeType == 31) {
            String[] features = FeatureUtil.toFeatures(featureValue, this.seq);

            if (features != null && features.length > 0) {
                for (int i = 0; i < features.length; i++) {
                    ret.add(features[i]);
                }
            }
        }
        return ret;
    }

}
